@@ -6,9 +6,9 @@ from pymasmovil.errors.exceptions import NewLineRequestRequiredParamsError
 
 class OrderItem(Contract):
 
-    _route = '/v2/order-items'
-    orderType = ''
-    lastModifiedDate = ''
+    _route = "/v2/order-items"
+    orderType = ""
+    lastModifiedDate = ""
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -17,19 +17,19 @@ class OrderItem(Contract):
     def get(cls, session, order_item_id):
         contract = super().get(session, order_item_id)
 
-        return cls(**contract['orderDetail'])
+        return cls(**contract["orderDetail"])
 
     @classmethod
     def create(cls, session, account, **new_order_item):
         """
-            Creates an order-item and posts it to the given account
+        Creates an order-item and posts it to the given account
 
-            :param account: account where we want to add the order-item
-            :param **new_order_item:
-            :return: order-item instance
+        :param account: account where we want to add the order-item
+        :param **new_order_item:
+        :return: order-item instance
         """
 
-        post_route = '/v1/accounts/{}/order-items'.format(account.id)
+        post_route = "/v1/accounts/{}/order-items".format(account.id)
 
         cls._check_required_attributes(new_order_item)
 
@@ -40,31 +40,33 @@ class OrderItem(Contract):
         return OrderItem(**new_line_request.to_order_item())
 
     def _check_required_attributes(new_order_item):
-        """ Check that all compulsary attributes for a portability request
-        are present in the request dynamic fields """
+        """Check that all compulsary attributes for a portability request
+        are present in the request dynamic fields"""
 
-        required_attributes = ['idLine', 'documentType', 'iccid', 'productInfo']
+        required_attributes = ["idLine", "documentType", "iccid", "productInfo"]
 
         is_portability = False
-        new_line_info = new_order_item['lineInfo'][0]
+        new_line_info = new_order_item["lineInfo"][0]
 
-        if new_line_info.get('phoneNumber'):
+        if new_line_info.get("phoneNumber"):
             is_portability = True
-            required_attributes.extend(["docid", "donorOperator", "portabilityDate"])
+            required_attributes.extend(["docid", "donorOperator"])
 
-        if new_line_info.get('documentType') == "CIF":
+        if new_line_info.get("documentType") == "CIF":
             # Organization client
             required_attributes.append("corporateName")
 
-        elif new_line_info.get('documentType') in ("NIF", "NIE", "Pasaporte"):
+        elif new_line_info.get("documentType") in ("NIF", "NIE", "Pasaporte"):
             # Particular client
             required_attributes.extend(["name", "surname"])
 
-        order_item_filled_attributes = set(filter(
-            new_line_info.get,
-            new_line_info.keys()))
+        order_item_filled_attributes = set(
+            filter(new_line_info.get, new_line_info.keys())
+        )
 
         missing_attributes = set(required_attributes) - order_item_filled_attributes
 
         if len(missing_attributes) != 0:
-            raise NewLineRequestRequiredParamsError(is_portability, sorted(missing_attributes))
+            raise NewLineRequestRequiredParamsError(
+                is_portability, sorted(missing_attributes)
+            )
